==> apache-doris-2.0.10-src.tar.gz: apache-doris-2.0.10-src/fe/fe-core/src/main/java/org/apache/doris/nereids/types/coercion/IntegralType.java <==
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

package org.apache.doris.nereids.types.coercion;

import org.apache.doris.nereids.types.BigIntType;
import org.apache.doris.nereids.types.DataType;

/**
 * Abstract class for all integral data type in Nereids.
 */
public class IntegralType extends NumericType {

    public static final IntegralType INSTANCE = new IntegralType();

    @Override
    public DataType defaultConcreteType() {
        return BigIntType.INSTANCE;
    }

    @Override
    public boolean acceptsType(AbstractDataType other) {
        return other instanceof IntegralType;
    }

    @Override
    public String simpleString() {
        return "integral";
    }

    public boolean widerThan(IntegralType other) {
        return this.width() > other.width();
    }
}

==> apache-doris-4.0.1-rc02-src.tar.gz: apache-doris-4.0.1-rc02-src/fe/fe-core/src/main/java/org/apache/doris/nereids/types/coercion/IntegralType.java <==
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

package org.apache.doris.nereids.types.coercion;

import org.apache.doris.nereids.types.BigIntType;
import org.apache.doris.nereids.types.DataType;

import org.apache.commons.lang3.NotImplementedException;

/**
 * Abstract class for all integral data type in Nereids.
 */
public class IntegralType extends NumericType {

    public static final IntegralType INSTANCE = new IntegralType();

    @Override
    public DataType defaultConcreteType() {
        return BigIntType.INSTANCE;
    }

    @Override
    public boolean acceptsType(DataType other) {
        return other instanceof IntegralType;
    }

    @Override
    public String simpleString() {
        return "integral";
    }

    public boolean widerThan(IntegralType other) {
        return this.width() > other.width();
    }

    // The maximum number of digits that Integer can represent.
    public int range() {
        throw new NotImplementedException("should be implemented by derived class");
    }
}
